@@ -13,8 +13,8 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 4977 $
-#:#  Last changed: $Date: 2021-06-09 15:58:25 +0200 (Wed, 09 Jun 2021) $
+#:#  File version: $Revision: 5177 $
+#:#  Last changed: $Date: 2021-08-18 10:42:27 +0200 (Mi, 18 Aug 2021) $
 #:#  Last changed by: $Author: pahlke $
 #:# 
 
@@ -1220,10 +1220,10 @@
 	}
 	
 	if (stageResults$isOneSampleDataset()) {
-		subTitle <- paste0("Stage = ", stage, ", # of remaining subjects = ", 
+		subtitle <- paste0("Stage = ", stage, ", # of remaining subjects = ", 
 			sum(nPlanned), ", sd = ", .formatSubTitleValue(assumedStDev, "assumedStDev"))
 	} else {
-		subTitle <- paste0("Stage = ", stage, ", # of remaining subjects = ", 
+		subtitle <- paste0("Stage = ", stage, ", # of remaining subjects = ", 
 			sum(nPlanned), ", sd = ", .formatSubTitleValue(assumedStDev, "assumedStDev"), 
 			", allocation ratio = ", .formatSubTitleValue(allocationRatioPlanned, "allocationRatioPlanned"))
 	}
@@ -1235,7 +1235,7 @@
 		main = C_PLOT_MAIN_CONDITIONAL_POWER_WITH_LIKELIHOOD,
 		xlab = "Effect size",
 		ylab = C_PLOT_YLAB_CONDITIONAL_POWER_WITH_LIKELIHOOD,
-		sub = subTitle
+		sub = subtitle
 	))
 }	
 
