@@ -13,8 +13,8 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 4977 $
-#:#  Last changed: $Date: 2021-06-09 15:58:25 +0200 (Wed, 09 Jun 2021) $
+#:#  File version: $Revision: 5177 $
+#:#  Last changed: $Date: 2021-08-18 10:42:27 +0200 (Mi, 18 Aug 2021) $
 #:#  Last changed by: $Author: pahlke $
 #:# 
 
@@ -296,11 +296,11 @@
 	)
 	
 	piControl <- matrix(rep(NA_real_, kMax), 1, kMax)
-	piTreatments <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	testStatistics <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	overallTestStatistics <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	separatePValues <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	overallPValues <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)	
+	piTreatments <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	testStatistics <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	overallTestStatistics <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	separatePValues <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	overallPValues <- matrix(NA_real_, nrow = gMax, ncol = kMax)	
 	dimnames(testStatistics) = list(paste("arm ", 1:gMax, sep = ""), paste("stage ", (1:kMax), sep = ""))
 	dimnames(overallTestStatistics) = list(paste("arm ", 1:gMax, sep = ""), 
 		paste("stage ", (1:kMax), sep = ""))
@@ -458,9 +458,9 @@
 	
 	# Calculation of single stage adjusted p-Values and overall test statistics
 	# for determination of RCIs 
-	singleStepAdjustedPValues <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	combInverseNormal <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
-	combFisher <- matrix(rep(NA_real_, gMax * kMax), gMax, kMax)
+	singleStepAdjustedPValues <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	combInverseNormal <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+	combFisher <- matrix(NA_real_, nrow = gMax, ncol = kMax)
 	
 	if (.isTrialDesignInverseNormal(design)) {	
 		weightsInverseNormal <- stageResults$weightsInverseNormal
@@ -1239,7 +1239,7 @@
 		}
 	}	
 	
-	subTitle <- paste0("Intersection test = ", intersectionTest, 
+	subtitle <- paste0("Intersection test = ", intersectionTest, 
 		", stage = ", stage, ", # of remaining subjects = ", 
 		sum(nPlanned), ", control rate = ", .formatSubTitleValue(piControl, "piControl") , 
 		", allocation ratio = ", .formatSubTitleValue(allocationRatioPlanned, "allocationRatioPlanned"))
@@ -1252,7 +1252,7 @@
 		main = C_PLOT_MAIN_CONDITIONAL_POWER_WITH_LIKELIHOOD,
 		xlab = "Treatment rate",
 		ylab = C_PLOT_YLAB_CONDITIONAL_POWER_WITH_LIKELIHOOD,
-		sub = subTitle
+		sub = subtitle
 	))
 }
 
