@@ -13,9 +13,9 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 4981 $
-#:#  Last changed: $Date: 2021-06-10 11:58:01 +0200 (Do, 10 Jun 2021) $
-#:#  Last changed by: $Author: pahlke $
+#:#  File version: $Revision: 5147 $
+#:#  Last changed: $Date: 2021-08-12 14:11:48 +0200 (Thu, 12 Aug 2021) $
+#:#  Last changed by: $Author: wassmer $
 #:# 
 
 .getTestStatisticsRates <- function(..., designNumber, informationRates, groups, normalApproximation,
@@ -818,14 +818,14 @@ getSimulationRates <- function(design = NULL, ...,
 	criticalValues <- design$criticalValues
 	kMax <- design$kMax
 	cols <- length(pi1)
-	sampleSizes <- matrix(0, kMax, cols)
-	rejectPerStage <- matrix(0, kMax, cols)
+	sampleSizes <- matrix(0, nrow = kMax, ncol = cols)
+	rejectPerStage <- matrix(0, nrow = kMax, ncol = cols)
 	overallReject <- rep(0, cols)
 	futilityPerStage <- matrix(0, kMax - 1, cols)
 	futilityStop <- rep(0, cols)
-	iterations <- matrix(0, kMax, cols)
+	iterations <- matrix(0, nrow = kMax, ncol = cols)
 	expectedNumberOfSubjects <- rep(0, cols)
-	conditionalPowerAchieved <- matrix(NA_real_, kMax, cols)
+	conditionalPowerAchieved <- matrix(NA_real_, nrow = kMax, ncol = cols)
 	
 	len <- length(pi1) * maxNumberOfIterations * kMax
 	dataIterationNumber <- rep(NA_real_, len)
